@@ -1,7 +1,7 @@
 package Validator::Custom;
 use Object::Simple -base;
 use 5.008001;
-our $VERSION = '1.00_04';
+our $VERSION = '1.00_05';
 
 use Carp 'croak';
 use Validator::Custom::Validation;
@@ -80,15 +80,15 @@ sub check_each {
   my ($self, $values, $name, $arg) = @_;
   
   if (@_ < 3) {
-    croak "value must be passed";
+    croak "values and the name of a checking function must be passed";
   }
   
   my $checks = $self->{checks} || {};
   
-  croak "Can't call \"$name\" check"
+  croak "Can't call \"$name\" checking function"
     unless $checks->{$name};
   
-  croak "values must be array refernce"
+  croak "values must be array reference"
     unless ref $values eq 'ARRAY';
   
   my $is_invalid;
@@ -107,15 +107,15 @@ sub filter_each {
   my ($self, $values, $name, $arg) = @_;
   
   if (@_ < 3) {
-    croak "value must be passed";
+    croak "values and the name of a filtering function must be passed";
   }
   
   my $filters = $self->{filters} || {};
   
-  croak "Can't call \"$name\" filter"
+  croak "Can't call \"$name\" filtering function"
     unless $filters->{$name};
   
-  croak "values must be array refernce"
+  croak "values must be array reference"
     unless ref $values eq 'ARRAY';
   
   my $new_values = [];
@@ -131,12 +131,12 @@ sub check {
   my ($self, $value, $name, $arg) = @_;
 
   if (@_ < 3) {
-    croak "value must be passed";
+    croak "value and the name of a checking function must be passed";
   }
   
   my $checks = $self->{checks} || {};
   
-  croak "Can't call \"$name\" check"
+  croak "Can't call \"$name\" checking function"
     unless $checks->{$name};
   
   return $checks->{$name}->($self, $value, $arg);
@@ -146,12 +146,12 @@ sub filter {
   my ($self, $value, $name, $arg) = @_;
   
   if (@_ < 3) {
-    croak "value must be passed";
+    croak "value and the name of a filtering function must be passed";
   }
   
   my $filters = $self->{filters} || {};
   
-  croak "Can't call \"$name\" filter"
+  croak "Can't call \"$name\" filtering function"
     unless $filters->{$name};
   
   return $filters->{$name}->($self, $value, $arg);
@@ -819,7 +819,8 @@ Validator::Custom - HTML form Validation, simple and good flexibility
   if (@$favorite > 0) {
     $validation->add_failed(favorite => 'favorite must be selected more than one');
   }
-  elsif (!($vc->check_each($favorite, 'in',  ['001', '002', 'peach']))) {
+  # Check if favorite is one of the specified values
+  elsif (!($vc->check_each($favorite, 'in',  ['001', '002', '003']))) {
     $validation->add_failed(favorite => 'favorite is invalid');
   }
   
@@ -918,13 +919,13 @@ You can use C<int> checking function to check the value is integer.
 C<int> checking function is default one.
 Any checking function is available through C<check> method.
 
-If the check fail, you can add failed parameter name and that message
-using C<add_failed> method.
+When the check dosen't success, you can add failed parameter name and the message
+using C<add_failed> method of L<Validator::Custom::Validation> class.
   
   # Filter price to remove left-rigth space
   $price = $vc->filter($price, 'trim');
 
-You can use C<trim> filter function to trim left-rigth spaces.
+You can use C<trim> filtering function to trim left-rigth spaces.
   
   # Filter each value of favorite using "trim" filtering function
   $favorite = $vc->filter_each($favorite, 'trim');
@@ -935,7 +936,8 @@ You can use C<filter_each> method to filter each value of favorite.
   if (@$favorite > 0) {
     $validation->add_failed(favorite => 'favorite must be selected more than one');
   }
-  elsif (!($vc->check_each($favorite, 'in',  ['001', '002', 'peach']))) {
+  # Check if favorite is one of the specified values
+  elsif (!($vc->check_each($favorite, 'in',  ['001', '002', '003']))) {
     $validation->add_failed(favorite => 'favorite is invalid');
   }
 
@@ -948,7 +950,7 @@ see L<Validator::Custom/"CHECKING FUNCTIONS"> and L<Validator::Custom/"FILTERING
 
 If you check all input data is valid, use C<is_valid> method.
   
-  # Get result
+  # Check if validation result is valid
   if ($validation->is_valid) {
     # Success
   }
@@ -958,7 +960,7 @@ If you check all input data is valid, use C<is_valid> method.
 
 If you can check a input data is valid, use C<is_valid> method with parameter name.
   
-  # Know what is failed
+  # Check what parameter fail
   unless ($validation->is_valid('name')) {
     # ...
   }
@@ -968,19 +970,19 @@ You can get all failed parameter names using C<failed> method.
   # Get all failed parameter names
   my $failed = $validation->failed;
 
-You can get a failed parameter message using C<message>.
+You can get a failed parameter message using C<message> method.
 
   # Get a failed parameter message
   my $name_message = $validation->message('name');
 
-You can get all failed parameter messages.
+You can get all failed parameter messages using C<messages> method.
 
   # Get all failed parameter messages
   my $messages = $validation->messages;
 
-You can get all failed names and the messages as hash.
+You can get all failed names and the messages as hash reference using C<messages_to_hash> method.
 
-  # Get all failed parameter names and messages as hash
+  # Get all failed parameter names and the messages as hash reference
   my $messages_h = $validation->messages_to_hash;
 
 See also L<Validator::Custom::Validation>.
@@ -989,7 +991,7 @@ See also L<Validator::Custom::Validation>.
 
 =head3 1. Add checking function
 
-You can add your check function by C<add_check> method if you need.
+You can add your own checking function using C<add_check> method if you need.
 
   $vc->add_check(
     telephone => sub {
@@ -1004,11 +1006,11 @@ You can add your check function by C<add_check> method if you need.
   );
 
 Checking function receives three arguments,
-L<Validator::Custom> object as first argument,
-the value as second argument,
-the argument as third argument.
+First argument is L<Validator::Custom> object,
+Second argument is the value for checking,
+Third argument is the argument of checking function.
 
-You must return the result of validation, true or false value.
+Your Checking function must return true or false value.
 
 =head3 2. Add filtering function
 
@@ -1025,11 +1027,11 @@ You can add your filtering function by C<add_filter> method if you need.
   );
 
 Filtering function receives three arguments,
-L<Validator::Custom> object as first argument,
-the value as second argument,
-the argument as third argument.
+First argument is L<Validator::Custom> object,
+Second argument is the value for filtering.
+Third argument is the argument of filtering function.
 
-You must return the result of filtering.
+Your filtering function must return the result of filtering.
 
 =head1 CHECKING FUNCTIONS
 
@@ -1041,19 +1043,19 @@ You can call any checking function by C<check> method.
   my $value = 19;
   my $is_valid = $vc->check($value, 'int');
 
-Integer value.
+Check if the value is integer value.
 
-Valid example:
+Example of valid values:
 
   "-10"
   "234"
 
-Invalid example:
+Example of invalid values:
 
   "10.11"
   "abc"
 
-If you need to check the range of value, you can write the following way.
+If you also need to check the range of value, you can write the following way.
 
   my $is_valid =  $vc->check($value, 'int') && $value > 0;
 
@@ -1061,9 +1063,10 @@ If you need to check the range of value, you can write the following way.
   
   my $is_valid = $vc->check($value, 'number');
 
-Number. Number means integer or floating point number.
+Check if the value is number.
+Number means integer or decimal.
 
-Valid example:
+Example of valid values:
 
   '1'
   '123'
@@ -1072,23 +1075,23 @@ Valid example:
   '-100'
   '-100.789'
 
-Invalid example:
+Example of invalid values:
 
   'a';
   '1.a';
   'a.1';
 
-You can specify decimal part max digits with C<decimal_part_max> option.
+You can also specify decimal part max digits using C<decimal_part_max> option.
 
   my $is_valid = $vc->check($value, 'number', {decimal_part_max => 3});
 
-Valid example:
+Example of valid values:
 
   '123'
   '123.456'
   '-100.789'
 
-Invalid example:
+Example of invalid values:
 
   '123.4567'
   '-100.7891'
@@ -1097,14 +1100,15 @@ Invalid example:
   
   my $is_valid = $vc->check($value, 'ascii');
   
-Ascii graphic characters(hex 21-7e). Generally, you can use C<ascii_graphic> function
-for checking the characters of a password.
+Check if the value is Ascii graphic characters(hex 21-7e).
+Generally, C<ascii_graphic> function is used to
+check the characters of a password.
 
-Valid example:
+Example of valid values:
 
   "Ken!@-"
 
-Invalid example:
+Example of invalid values:
   
   "aa aa"
   "\taaa"
@@ -1114,15 +1118,15 @@ Invalid example:
   my $value = '001';
   my $is_valid = $vc->check($value, 'in', ['001', '002', '003']);
 
-Check if the value is one of the values of the array.
+Check if the value is one of the given values.
 
-Valid example:
+Example of valid values:
 
   '001'
   '002'
   '003'
 
-Invalid example:
+Example of invalid values:
 
   '004'
   '005'
@@ -1130,19 +1134,19 @@ Invalid example:
 =head1 FILTERING FUNCTIONS
 
 L<Validator::Custom> have the following default filtering functions.
-You can call any filtering function by C<filter> method.
+You can call any filtering function using C<filter> method.
 
 =head2 trim
 
   my $new_value = $vc->filter($value, 'trim');
 
 Trim leading and trailing white space.
-Trim unicode space character, not only C<[ \t\n\r\f]>.
+Note that trim function remove unicode space character, not only C<[ \t\n\r\f]>.
 
-Example:
+Filtering example:
 
-  Input  '  　Ken  '
-  Output 'Ken'
+  Input : '  　Ken  '
+  Output: 'Ken'
 
 =head2 remove_blank
 
@@ -1150,10 +1154,10 @@ Example:
 
 Remove blank character and undefined value from array reference.
 
-Example:
+Filtering example:
 
-  Input  [1, 2, '', undef, 4]
-  Output [1, 2, 4]
+  Input : [1, 2, '', undef, 4]
+  Output: [1, 2, 4]
 
 =head1 METHODS
 
@@ -1168,17 +1172,15 @@ Create a new L<Validator::Custom> object.
 
 =head2 add_check
 
-  $vc->add_check(%check);
-  $vc->add_check(\%check);
+  $vc->add_check(int => sub { ... });
 
-Add check function.
-It receives four arguments,
-Validator::Custom::Rule object, arguments of check function,
-current key name, and parameters
+Add a checking function.
+
+Example:
   
   $vc->add_check(
     int => sub {
-      my ($vc, $value, $args) = @_;
+      my ($vc, $value, $arg) = @_;
       
       my $is_valid = $value =~ /^\-?[\d]+$/;
       
@@ -1186,16 +1188,24 @@ current key name, and parameters
     }
   );
 
+Checking function receives three arguments,
+First argument is L<Validator::Custom> object,
+Second argument is the value for checking,
+Third argument is the argument of checking function.
+
+Your Checking function must return true or false value.
+
 =head2 add_filter
 
-Add filter function. 
-It receives four arguments,
-Validator::Custom::Rule object, arguments of check function,
-current key name, and parameters,
+  $vc->add_filter(trim => sub { ... });
+
+Add a filtering function. 
+
+Example:
 
   $vc->add_filter(
     trim => sub {
-      my ($vc, $value, $args) = @_;
+      my ($vc, $value, $arg) = @_;
       
       $value =~ s/^\s+//;
       $value =~ s/\s+$//;
@@ -1209,35 +1219,51 @@ current key name, and parameters,
   my $is_valid = $vc->check($value, 'int');
   my $is_valid = $vc->check($value, 'int', $arg);
 
-Run check.
+Execute a checking function.
+
+First argument is the value for checking.
+Second argument is the name of the checking funcion.
+Third argument is the argument of the checking function.
 
 =head2 check_each
 
   my $is_valid = $vc->check_each($values, 'int');
   my $is_valid = $vc->check_each($values, 'int', $arg);
 
-Run check all elements of array refernce.
-If more than one element is invalid, check_each reterun false.
+Execute a checking function to all elements of array reference.
+If more than one element is invalid, C<check_each> method return false.
+
+First argument is the values for checking, which must be array reference.
+Second argument is the name of the checking funcion.
+Third argument is the argument of the checking function.
 
 =head2 filter
 
   my $new_value = $vc->filter($value, 'trim');
   my $new_value = $vc->filter($value, 'trim', $arg);
 
-Run filter.
+Execute a filtering function.
+
+First argument is the value for filtering.
+Second argument is the name of the filtering funcion.
+Third argument is the argument of the filtering function.
 
 =head2 filter_each
 
   my $new_values = $vc->filter_each($values, 'trim');
   my $new_values = $vc->filter_each($values, 'trim', $arg);
 
-Run filter all elements of array reference.
+Execute a filtering function to all elements of array reference.
+
+First argument is the values for filtering, which must be array reference.
+Second argument is the name of the filtering funcion.
+Third argument is the argument of the filtering function.
 
 =head1 EXAMPLES
 
 Show you some examples to do some validation.
 
-Password checking.
+Password checking:
   
   my $password = 'abc';
   my $password2 = 'abc';
@@ -1261,7 +1287,7 @@ Password checking.
     # ...
   }
 
-Check box, selected at least 1.
+Check box, selected at least 1, one of the given values:
 
   my $favorite = ['001', '002'];
 
@@ -1281,24 +1307,24 @@ Check box, selected at least 1.
     # ...
   }
 
-Convert date string to Time::Piece object.
+Convert date string to L<Time::Piece> object.
 
   my $date = '2014/05/16';
   
   my $validation = $vc->validation;
   
   my $date_tp;
-  if (!length $datetime) {
+  if (!length $date) {
     $validation->add_failed(date => 'date must have length');
   }
   else {
-    eval { $date_tp = Time::Piece->strptime($datetime_tp, '%Y/%m/%d') };
+    eval { $date_tp = Time::Piece->strptime($date, '%Y/%m/%d') };
     if (!$date_tp) {
       $validation->add_failed(date => 'date value is invalid');
     }
   }
 
-Convert datetime string to Time::Piece object.
+Convert datetime string to L<Time::Piece> object.
 
   my $datetime = '2014/05/16 12:30:40';
   
@@ -1309,7 +1335,7 @@ Convert datetime string to Time::Piece object.
     $validation->add_failed(datetime => 'datetime must have length');
   }
   else {
-    eval { $datetime_tp = Time::Piece->strptime($datetime_tp, '%Y/%m/%d %H:%M:%S') };
+    eval { $datetime_tp = Time::Piece->strptime($datetime, '%Y/%m/%d %H:%M:%S') };
     if (!$datetime_tp) {
       $validation->add_failed(datetime => 'datetime value is invalid');
     }
@@ -1320,28 +1346,45 @@ Convert datetime string to Time::Piece object.
 =head2 I use Validator::Custom 0.xx yet. I want to see documentation of Version 0.xx.
 
 See L<Validator::Custom::Document::Version0>.
+This is complete document for L<Validator::Custom> version 0.xx.
 
-=head2 What point I take care of in Version 1.00.
+=head2 What point I take care of in Version 1.xx.
+
+=over 4
+
+=item *
 
 C<in_array> constraint function is renamed to C<in> checking function.
 
-C<trim> filter become triming unicode space characters, not only C<[ \t\n\r\f]>.
+=item *
+
+C<trim> filtering function becomes triming unicode space characters, not only C<[ \t\n\r\f]>.
+
+=item *
 
 C<decimal> constraint is renamed to C<number> checking function and simplified.
 
+=item *
+
 C<date_to_timepiece> checking function dosen't exist.
-About alternative way, see "EXAMPLES" "Convert date string to Time::Piece object".
+About alternative way, see the topic "Convert date string to Time::Piece object" in "EXAMPLES".
+
+=item *
 
 C<datetime_to_timepiece> checking function dosen't exists.
-About alternative way, see "EXAMPLES" "Convert datetime string to Time::Piece object".
+About alternative way, see the topic "Convert datetime string to Time::Piece object" in "EXAMPLES".
+
+=back
 
 =head2 How to create the corresponding checking functions in Version 0.xx constraint functions.
 
+I show some examples.
+
 space
 
   $vc->add_check(space => sub {
     my ($vc, $value, $arg) = @_;
-    defined $value && $value =~ '^[ \t\n\r\f]*$' ? 1 : 0;
+    return defined $value && $value =~ '^[ \t\n\r\f]*$' ? 1 : 0;
   });
 
 http_url
@@ -1398,7 +1441,9 @@ decimal
     }
   }
 
-=head2 How to create the corresponding filtering functions in Version 0.xx.
+=head2 How to create the corresponding filtering functions in Version 0.xx constraint functions.
+
+I show some examples.
 
 trim_collapse
 
